import router from '@/router'
import store from '@/store'
import { getToken, getUserInfo, initGoPage } from '@/utils/auth'
import getPageTitle from './utils/get-page-title'
import { setStorage } from './utils/storage'

// 获取用户信息
const userInfo = getUserInfo()
if (userInfo) {
  store.commit('user/SAVE_USER_INOF', userInfo)
}

// 路由白名单
const whiteList = ['/login']

// 路由拦截器
router.beforeEach(async(to, from, next) => {
  // 获取token
  const hasToken = getToken()

  // 设置页面标题
  document.title = getPageTitle(to.meta.title)
  if (hasToken) {
    // 如果是访问登录页面，强制跳转到首页
    if (to.path === '/login') {
      next({ path: initGoPage() })
    } else {
      // 加载国家列表并保存到store
      store.dispatch('app/setCountry')
      // 判断当前用户是否拥有角色
      const hasRoles = store.getters.roles && store.getters.roles.length > 0
      if (hasRoles) {
        // 放行
        next()
      } else {
        try {
          // 代理状态更换时清空全部页面标签
          if (store.getters.isChangeProxy) {
            store.commit('tagsView/CLEAR_ALL_VIEW')
          }
          // 获取当前用户所分配的角色
          const roles = await store.dispatch('user/getRoles')
          // 根据用户角色获取路由配置
          const accessRoutes = await store.dispatch('permission/generateRoutes', roles)
          // 添加路由配置
          router.addRoutes(accessRoutes)
          // 放行
          next({ ...to, replace: true })
        } catch (err) {
          store.dispatch('user/logout')
        }
      }
    }
  } else {
    if (whiteList.indexOf(to.path) !== -1) {
      // 放行
      next()
    } else {
      if (Object.keys(to.query).length > 0) {
        setStorage('redirect-route-query', JSON.stringify(to.query))
      }
      next(`/login?redirect=${to.path}`)
    }
  }
})
